deriva.config package
=====================

Submodules
----------

deriva.config.acl\_config module
--------------------------------

.. automodule:: deriva.config.acl_config
    :members:
    :undoc-members:
    :show-inheritance:

deriva.config.annotation\_config module
---------------------------------------

.. automodule:: deriva.config.annotation_config
    :members:
    :undoc-members:
    :show-inheritance:

deriva.config.base\_config module
---------------------------------

.. automodule:: deriva.config.base_config
    :members:
    :undoc-members:
    :show-inheritance:

deriva.config.dump\_catalog\_annotations module
-----------------------------------------------

.. automodule:: deriva.config.dump_catalog_annotations
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: deriva.config
    :members:
    :undoc-members:
    :show-inheritance:
